pub fn check_expected_target_syntax(
ctx: &Context<'_>,
output: &mut TokenStream,
target: DdOptVal<Target>,
)Expand description
Main entrypoint
Checks that output can be parsed as target.
If not, replaces output with something which will generate
compiler error(s) which the user will find helpful:
- A
compile_error!invocation with the original error span - include_file!` for a generated temporary file containing the text of the output, so that the compiler will point to the actual error.